@@ -8,16 +8,23 @@ from sentry.plugins.bases.notify import NotificationPlugin
 import sentry_dingding
 from .forms import DingDingOptionsForm
 
+from sentry.utils.compat import mock
+
+from sentry.models import Environment, Release, GroupInboxReason
+from sentry.models.groupinbox import add_group_to_inbox, remove_group_from_inbox
+from sentry.testutils import APITestCase, SnubaTestCase
+from sentry.testutils.helpers.datetime import before_now, iso_format
+
 DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"
 
 
-class DingDingPlugin(NotificationPlugin):
+class DingDingPlugin(NotificationPlugin,APITestCase, SnubaTestCase):
     """
     Sentry plugin to send error counts to DingDing.
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.17'
+    version = '1.0.18'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
